#
# spec file for package python-Pygments
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Pygments
Version:        1.6
Release:        10.5
Url:            http://pygments.org
Summary:        Pygments is a syntax highlighting package written in Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/P/Pygments/Pygments-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-nose
BuildRequires:  python-setuptools
Requires:       python-setuptools
Provides:       python-pygments = %{version}
Obsoletes:      python-pygments < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Pygments is a syntax highlighting package written in Python.

It is a generic syntax highlighter for general use in all kinds of software
such as forum systems, wikis or other applications that need to prettify
source code. Highlights are:

 * a wide range of common languages and markup formats is supported
 * special attention is paid to details, increasing quality by a fair amount
 * support for new languages and formats are added easily
 * a number of output formats, presently HTML, LaTeX, RTF, SVG, all image
   formats that PIL supports and ANSI sequences
 * it is usable as a command-line tool and as a library
 * ... and it highlights even Brainfuck!

%prep
%setup -q -n Pygments-%{version}
# Remove non-oss licensed files, see bnc# 760344
rm tests/examplefiles/{Sorting,test}.mod

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -Dm0644 docs/pygmentize.1 %{buildroot}%{_mandir}/man1/pygmentize.1

%check
nosetests

%files
%defattr(-,root,root,-)
%doc AUTHORS CHANGES TODO docs/build
%{_bindir}/pygmentize
%{_mandir}/man1/pygmentize.1*
%{python_sitelib}/pygments/
%{python_sitelib}/Pygments-%{version}-py%{py_ver}.egg-info/

%changelog
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri May  3 2013 toddrme2178@gmail.com
- Update to version 1.6:
  - Lexers added
  - Fix unquoted HTML attribute lexing in Opa .
  - The HTML formatter now supports linking to tags using CTags files, when the
    python-ctags package is installed .
  - The HTML formatter now has a "linespans" option that wraps every line in a
    <span> tag with a specific id .
  - When deriving a lexer from another lexer with token definitions, definitions
    for states not in the child lexer are now inherited.  If you override a state
    in the child lexer, an "inherit" keyword has been added to insert the base
    state at that position .
  - The C family lexers now inherit token definitions from a common base class,
    removing code duplication .
  - Use "colorama" on Windows for console color output .
  - Fix Template Haskell highlighting .
  - Fix some S/R lexer errors .
  - Fix a bug in the Prolog lexer with names that start with 'is' .
  - Rewrite Dylan lexer, add Dylan LID lexer .
  - Add a Java quickstart document .
  - Add a "external/autopygmentize" file that can be used as .lessfilter .
* Thu May  3 2012 toddrme2178@gmail.com
- Removed files with non-oss license, see bnc#760344
- Cleanups in python 2 and python 3 spec files
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Mon Mar 12 2012 saschpe@gmx.de
- Update to version 1.5:
  - Fix Python 3 terminal highlighting with pygmentize
  - In the LaTeX formatter, escape special &, < and > chars
  - In the LaTeX formatter, fix display problems for styles with token
    background colors
  - Enhancements to the Squid conf lexer
  - Several fixes to the reStructuredText lexer
  - Recognize methods in the ObjC lexer
  - Fix Lua "class" highlighting: it does not have classes
  - Fix degenerate regex in Scala lexer  and highlighting bugs
  - Fix number pattern order in Ocaml lexer
  - Fix generic type highlighting in ActionScript 3
  - Fixes to the Clojure lexer
  - Fix degenerate regex in Nemerle lexer
  - Fix infinite looping in CoffeeScript lexer
  - Fix crashes and analysis with ObjectiveC lexer
  - Add some Fortran 2003 keywords.
  - Fix Boo string regexes
  - Add "rrt" style
  - Fix infinite looping in Darcs Patch lexer.
  - Lots of misc fixes to character-eating bugs and ordering problems in many
    different lexers.
* Tue Jan 24 2012 bwiedemann@suse.com
- fix Obsoletes
* Fri Sep 23 2011 saschpe@suse.de
- Disable tests again, breaks i586 build
* Thu Sep 22 2011 saschpe@suse.de
- Fixed license to BSD-2-Clause
* Sun Sep 11 2011 saschpe@gmx.de
- Change license to BSD-3-Clause (SPDX style)
- Removed %%clean section (has sane default)
- Added python-distribute requirement
* Sun Jul  3 2011 saschpe@gmx.de
- Renamed to 'python-Pygments', obsoletes 'python-pygments'
* Mon Feb 21 2011 nix@opensuse.org
- Update to version 1.4
- Compress the tarball with bz2
* Tue Sep 14 2010 coolo@novell.com
- correct email addresses
* Fri Jun 18 2010 coolo@novell.com
- update to 1.3.1 (1.4 is too late, but is known to fix
  http://dev.pocoo.org/projects/pygments/ticket/507 )
* Fri Feb 12 2010 bitdealer@opensuse.org
- Updated to 1.2.2
* Fri Oct  9 2009 bitdealer@opensuse.org
- Updated to 1.1.1
* Tue Dec  9 2008 cfarrell1980@gmail.com
- Updated to version 1.0
* Thu Jun 21 2007 judas_iscariote@shorewall.net
- Initial package version.
